#!/usr/bin/env python3
from setuptools import setup, find_packages


def read_requirements(filename):
    return [req.strip() for req in open(filename)]


requirements = read_requirements('requirements.txt')
dev_requirements = read_requirements('requirements-dev.txt')


setup(
    name='breadbot',
    version=open('VERSION').read().strip(),
    author='Lucidiot',
    packages=find_packages(
        exclude=["*.tests", "*.tests.*", "tests.*", "tests"],
    ),
    package_data={
        '': ['LICENSE', 'README', 'README.rst'],
        'breadbot': ['data/*.yaml', 'data/*.txt', 'data/*.json'],
    },
    entry_points={
        'console_scripts': ['breadbot=breadbot.__main__:main'],
    },
    python_requires='>=3.7',
    install_requires=requirements,
    extras_require={
        'dev': dev_requirements,
    },
    license='GNU General Public License 3',
    description='Breadpunk Bread Bot',
    long_description=open('README.rst').read(),
    long_description_content_type='text/x-rst',
    keywords="irc bot bread breadpunk",
    url="https://tildegit.org/breadpunk/breadbot",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: No Input/Output (Daemon)",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Communications :: Chat :: Internet Relay Chat",
    ],
    project_urls={
        "Source Code": "https://tildegit.org/breadpunk/breadbot",
        "Bug Tracker": "https://tildegit.org/breadpunk/breadbot/issues"
    }
)
